Available documentation for Nilearn
===================================

Web-based documentation is available for versions listed below:

* `Nilearn latest - dev documentation <http://nilearn.github.io/dev/>`_
* `Nilearn latest - stable documentation <http://nilearn.github.io/stable/>`_
* `Nilearn 0.12.0 documentation <http://nilearn.github.io/0.12.0/>`_
* `Nilearn 0.11.1 documentation <http://nilearn.github.io/0.11.1/>`_
* `Nilearn 0.11.0 documentation <http://nilearn.github.io/0.11.0/>`_
* `Nilearn 0.10.3 documentation <http://nilearn.github.io/0.10.3/>`_
* `Nilearn 0.10.2 documentation <http://nilearn.github.io/0.10.2/>`_
* `Nilearn 0.10.0 documentation <http://nilearn.github.io/0.10.0/>`_
* `Nilearn 0.9.2 documentation <http://nilearn.github.io/0.9.2/>`_
* `Nilearn 0.9.1 documentation <http://nilearn.github.io/0.9.1/>`_
* `Nilearn 0.9.0 documentation <http://nilearn.github.io/0.9.0/>`_
* `Nilearn 0.8.1 documentation <http://nilearn.github.io/0.8.1/>`_
* `Nilearn 0.8.0 documentation <http://nilearn.github.io/0.8.0/>`_
* `Nilearn 0.7.1 documentation <http://nilearn.github.io/0.7.1/>`_
* `Nilearn 0.7.0 documentation <http://nilearn.github.io/0.7.0/>`_
